package main

import (
        "fmt"
        "context"
	"errors"
        "database/sql"
	"github.com/uptrace/bun"
        "github.com/uptrace/bun/extra/bundebug"
	"github.com/uptrace/bun/dialect/pgdialect"
	"github.com/uptrace/bun/driver/pgdriver"
)

var feeds		[]Feed
var categories		[]Category
var entries		[]Entry
var users		[]User

func main() {
  var err		error
  ctx := context.Background()
  dsn := "postgres://apache:@localhost:5432/miniflux?sslmode=disable"
  // dsn := "unix://user:pass@dbname/var/run/postgresql/.s.PGSQL.5432"
  sqldb := sql.OpenDB(pgdriver.NewConnector(pgdriver.WithDSN(dsn)))
  db := bun.NewDB(sqldb, pgdialect.New())

  db.AddQueryHook(bundebug.NewQueryHook(
  	bundebug.WithVerbose(true),
  	bundebug.FromEnv("BUNDEBUG"),
  ))

  
  // Turn these into funcs with error handling, logging, return vals etc. 
  feederr := db.NewSelect().Model(&feeds).OrderExpr("title ASC").Limit(10).Scan(ctx)
  
  if feederr != nil {
    errors.Join(feederr, err)
  }
  categoryerr := db.NewSelect().Model(&categories).OrderExpr("title ASC").Scan(ctx)
  if categoryerr != nil {
    errors.Join(categoryerr, err)
  }
  entryerr := db.NewSelect().Model(&entries).OrderExpr("published_at ASC").Limit(10).Scan(ctx)
  if entryerr != nil {
    errors.Join(entryerr, err)
  }
  usererr := db.NewSelect().Model(&users).OrderExpr("id ASC").Scan(ctx)
  if usererr != nil {
    errors.Join(usererr, err)
  }
  fmt.Printf("%+v\n", entries)
  fmt.Printf("%+v\n", categories)
  fmt.Printf("%+v\n", feeds)
  fmt.Printf("%+v\n", users)
// 
}
